==> ejc-panhuo-api-3.0.0-20200824.033313-31-sources.jar: com/ejianc/business/panhuo/vo/WbuyVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 求购实体
 * 
 * @author generator
 * 
 */
public class WbuyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 求购编号
    private java.lang.Long buyer; // 求购人
    private java.lang.String buyerName; // 求购人名称
    private java.lang.String mainimgPath; // 资产主图URL
    private java.lang.String title; // 求购标题
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date endDate; // 需求截止日期
    private java.lang.Long projectId; // 项目主键
    private java.lang.Long orgId; // 组织主键
    private java.lang.String orgName; // 组织名称
    private java.lang.String projectName; // 项目名称
    private java.lang.Long addressId; // 地址主键
    private java.lang.String addressName; // 详细地址
    private java.lang.String phone; // 联系方式
    private java.lang.String name; // 联系人
    private java.lang.Double lon; // 经度
    private java.lang.Double lat; // 纬度
    private java.lang.String firstLocation; // 所在地一级区域
    private java.lang.String secondLocation; // 所在地二级区域
    private java.lang.String thirdLocation; // 所在地三级区域
    private java.lang.String fourthLocation; // 所属城市
    private java.lang.String location; // 所在地末级区域
    @JsonFormat(
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private java.util.Date buyTime; // 求购发布时间
    @JsonFormat(
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private java.util.Date endbuyTime; // 停止求购时间
    private java.lang.Integer status; // 求购状态(0-求购中,1-已关闭，2-暂存)
    private java.lang.Integer closeType; // 关闭类型0-手动关闭,1-到期关闭
    private java.lang.Long closer; // 关闭人
    private java.lang.String note; // 求购说明
    private java.lang.String labelName; // 标签名称

    private java.lang.Integer isCollect; // 是否收藏
    private java.lang.Long collectId; // 收藏主键

    // 标签子表
    private List<LabeldetailVO> labels = new ArrayList<>();

    // 图片子表
    private List<ImgdetailVO> imgsPath = new ArrayList<>();

    // 求购物资子表
    private List<CategoryVO> materialDetails = new ArrayList<>();

    public List<LabeldetailVO> getLabels() {
        return labels;
    }

    public void setLabels(List<LabeldetailVO> labels) {
        this.labels = labels;
    }

    public List<ImgdetailVO> getImgsPath() {
        return imgsPath;
    }

    public void setImgsPath(List<ImgdetailVO> imgsPath) {
        this.imgsPath = imgsPath;
    }

    public List<CategoryVO> getMaterialDetails() {
        return materialDetails;
    }

    public void setMaterialDetails(List<CategoryVO> materialDetails) {
        this.materialDetails = materialDetails;
    }

    public Integer getIsCollect() {
        return isCollect;
    }

    public void setIsCollect(Integer isCollect) {
        this.isCollect = isCollect;
    }

    public Long getCollectId() {
        return collectId;
    }

    public void setCollectId(Long collectId) {
        this.collectId = collectId;
    }

    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }

    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }

    /**
     * 求购编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 求购编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 求购人
     */
    public java.lang.Long getBuyer() {
        return buyer;
    }

    /**
     * 求购人
     */
    public void setBuyer(java.lang.Long buyer) {
        this.buyer = buyer;
    }
    /**
     * 求购人名称
     */
    public java.lang.String getBuyerName() {
        return buyerName;
    }

    /**
     * 求购人名称
     */
    public void setBuyerName(java.lang.String buyerName) {
        this.buyerName = buyerName;
    }
    /**
     * 资产主图URL
     */
    public java.lang.String getMainimgPath() {
        return mainimgPath;
    }

    /**
     * 资产主图URL
     */
    public void setMainimgPath(java.lang.String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    /**
     * 求购标题
     */
    public java.lang.String getTitle() {
        return title;
    }

    /**
     * 求购标题
     */
    public void setTitle(java.lang.String title) {
        this.title = title;
    }
    /**
     * 需求截止日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 需求截止日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 项目主键
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目主键
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织主键
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 地址主键
     */
    @ReferSerialTransfer(referCode="panhuo-addressRef")
    public java.lang.Long getAddressId() {
        return addressId;
    }

    /**
     * 地址主键
     */
    @ReferDeserialTransfer
    public void setAddressId(java.lang.Long addressId) {
        this.addressId = addressId;
    }
    /**
     * 详细地址
     */
    public java.lang.String getAddressName() {
        return addressName;
    }

    /**
     * 详细地址
     */
    public void setAddressName(java.lang.String addressName) {
        this.addressName = addressName;
    }
    /**
     * 联系方式
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系方式
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 联系人
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 联系人
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 所在地一级区域
     */
    public java.lang.String getFirstLocation() {
        return firstLocation;
    }

    /**
     * 所在地一级区域
     */
    public void setFirstLocation(java.lang.String firstLocation) {
        this.firstLocation = firstLocation;
    }
    /**
     * 所在地二级区域
     */
    public java.lang.String getSecondLocation() {
        return secondLocation;
    }

    /**
     * 所在地二级区域
     */
    public void setSecondLocation(java.lang.String secondLocation) {
        this.secondLocation = secondLocation;
    }
    /**
     * 所在地三级区域
     */
    public java.lang.String getThirdLocation() {
        return thirdLocation;
    }

    /**
     * 所在地三级区域
     */
    public void setThirdLocation(java.lang.String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    /**
     * 所属城市
     */
    public java.lang.String getFourthLocation() {
        return fourthLocation;
    }

    /**
     * 所属城市
     */
    public void setFourthLocation(java.lang.String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    /**
     * 所在地末级区域
     */
    public java.lang.String getLocation() {
        return location;
    }

    /**
     * 所在地末级区域
     */
    public void setLocation(java.lang.String location) {
        this.location = location;
    }
    /**
     * 求购发布时间
     */
    public java.util.Date getBuyTime() {
        return buyTime;
    }

    /**
     * 求购发布时间
     */
    public void setBuyTime(java.util.Date buyTime) {
        this.buyTime = buyTime;
    }
    /**
     * 停止求购时间
     */
    public java.util.Date getEndbuyTime() {
        return endbuyTime;
    }

    /**
     * 停止求购时间
     */
    public void setEndbuyTime(java.util.Date endbuyTime) {
        this.endbuyTime = endbuyTime;
    }
    /**
     * 求购状态(0-求购中,1-已关闭，2-暂存)
     */
    public java.lang.Integer getStatus() {
        return status;
    }

    /**
     * 求购状态(0-求购中,1-已关闭，2-暂存)
     */
    public void setStatus(java.lang.Integer status) {
        this.status = status;
    }
    /**
     * 关闭类型0-手动关闭,1-到期关闭
     */
    public java.lang.Integer getCloseType() {
        return closeType;
    }

    /**
     * 关闭类型0-手动关闭,1-到期关闭
     */
    public void setCloseType(java.lang.Integer closeType) {
        this.closeType = closeType;
    }
    /**
     * 关闭人
     */
    public java.lang.Long getCloser() {
        return closer;
    }

    /**
     * 关闭人
     */
    public void setCloser(java.lang.Long closer) {
        this.closer = closer;
    }
    /**
     * 求购说明
     */
    public java.lang.String getNote() {
        return note;
    }

    /**
     * 求购说明
     */
    public void setNote(java.lang.String note) {
        this.note = note;
    }
    /**
     * 标签名称
     */
    public java.lang.String getLabelName() {
        return labelName;
    }

    /**
     * 标签名称
     */
    public void setLabelName(java.lang.String labelName) {
        this.labelName = labelName;
    }
    
}

==> ejc-panhuo-api-3.0.0-20200824.065433-32-sources.jar: com/ejianc/business/panhuo/vo/WbuyVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 求购实体
 * 
 * @author generator
 * 
 */
public class WbuyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 求购编号
    private java.lang.Long buyer; // 求购人
    private java.lang.String buyerName; // 求购人名称
    private java.lang.String mainimgPath; // 资产主图URL
    private java.lang.String title; // 求购标题
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date endDate; // 需求截止日期
    private java.lang.Long projectId; // 项目主键
    private java.lang.Long orgId; // 组织主键
    private java.lang.String orgName; // 组织名称
    private java.lang.String projectName; // 项目名称
    private java.lang.Long addressId; // 地址主键
    private java.lang.String addressName; // 详细地址
    private java.lang.String phone; // 联系方式
    private java.lang.String name; // 联系人
    private java.lang.Double lon; // 经度
    private java.lang.Double lat; // 纬度
    private java.lang.String firstLocation; // 所在地一级区域
    private java.lang.String secondLocation; // 所在地二级区域
    private java.lang.String thirdLocation; // 所在地三级区域
    private java.lang.String fourthLocation; // 所属城市
    private java.lang.String location; // 所在地末级区域
    @JsonFormat(
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private java.util.Date buyTime; // 求购发布时间
    @JsonFormat(
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private java.util.Date endbuyTime; // 停止求购时间
    private java.lang.Integer status; // 求购状态(0-求购中,1-已关闭，2-暂存)
    private java.lang.Integer closeType; // 关闭类型0-手动关闭,1-到期关闭
    private java.lang.Long closer; // 关闭人
    private java.lang.String note; // 求购说明
    private java.lang.String labelName; // 标签名称

    private java.lang.Integer isCollect; // 是否收藏
    private java.lang.Long collectId; // 收藏主键
    private java.lang.String distance; // 距离

    // 标签子表
    private List<LabeldetailVO> labels = new ArrayList<>();

    // 图片子表
    private List<ImgdetailVO> imgsPath = new ArrayList<>();

    // 求购物资子表
    private List<CategoryVO> materialDetails = new ArrayList<>();

    public List<LabeldetailVO> getLabels() {
        return labels;
    }

    public void setLabels(List<LabeldetailVO> labels) {
        this.labels = labels;
    }

    public List<ImgdetailVO> getImgsPath() {
        return imgsPath;
    }

    public void setImgsPath(List<ImgdetailVO> imgsPath) {
        this.imgsPath = imgsPath;
    }

    public List<CategoryVO> getMaterialDetails() {
        return materialDetails;
    }

    public void setMaterialDetails(List<CategoryVO> materialDetails) {
        this.materialDetails = materialDetails;
    }

    public Integer getIsCollect() {
        return isCollect;
    }

    public void setIsCollect(Integer isCollect) {
        this.isCollect = isCollect;
    }

    public Long getCollectId() {
        return collectId;
    }

    public void setCollectId(Long collectId) {
        this.collectId = collectId;
    }

    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }

    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }

    public String getDistance() {
        return distance;
    }

    public void setDistance(String distance) {
        this.distance = distance;
    }

    /**
     * 求购编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 求购编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 求购人
     */
    public java.lang.Long getBuyer() {
        return buyer;
    }

    /**
     * 求购人
     */
    public void setBuyer(java.lang.Long buyer) {
        this.buyer = buyer;
    }
    /**
     * 求购人名称
     */
    public java.lang.String getBuyerName() {
        return buyerName;
    }

    /**
     * 求购人名称
     */
    public void setBuyerName(java.lang.String buyerName) {
        this.buyerName = buyerName;
    }
    /**
     * 资产主图URL
     */
    public java.lang.String getMainimgPath() {
        return mainimgPath;
    }

    /**
     * 资产主图URL
     */
    public void setMainimgPath(java.lang.String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    /**
     * 求购标题
     */
    public java.lang.String getTitle() {
        return title;
    }

    /**
     * 求购标题
     */
    public void setTitle(java.lang.String title) {
        this.title = title;
    }
    /**
     * 需求截止日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 需求截止日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 项目主键
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目主键
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织主键
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 地址主键
     */
    @ReferSerialTransfer(referCode="panhuo-addressRef")
    public java.lang.Long getAddressId() {
        return addressId;
    }

    /**
     * 地址主键
     */
    @ReferDeserialTransfer
    public void setAddressId(java.lang.Long addressId) {
        this.addressId = addressId;
    }
    /**
     * 详细地址
     */
    public java.lang.String getAddressName() {
        return addressName;
    }

    /**
     * 详细地址
     */
    public void setAddressName(java.lang.String addressName) {
        this.addressName = addressName;
    }
    /**
     * 联系方式
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系方式
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 联系人
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 联系人
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 所在地一级区域
     */
    public java.lang.String getFirstLocation() {
        return firstLocation;
    }

    /**
     * 所在地一级区域
     */
    public void setFirstLocation(java.lang.String firstLocation) {
        this.firstLocation = firstLocation;
    }
    /**
     * 所在地二级区域
     */
    public java.lang.String getSecondLocation() {
        return secondLocation;
    }

    /**
     * 所在地二级区域
     */
    public void setSecondLocation(java.lang.String secondLocation) {
        this.secondLocation = secondLocation;
    }
    /**
     * 所在地三级区域
     */
    public java.lang.String getThirdLocation() {
        return thirdLocation;
    }

    /**
     * 所在地三级区域
     */
    public void setThirdLocation(java.lang.String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    /**
     * 所属城市
     */
    public java.lang.String getFourthLocation() {
        return fourthLocation;
    }

    /**
     * 所属城市
     */
    public void setFourthLocation(java.lang.String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    /**
     * 所在地末级区域
     */
    public java.lang.String getLocation() {
        return location;
    }

    /**
     * 所在地末级区域
     */
    public void setLocation(java.lang.String location) {
        this.location = location;
    }
    /**
     * 求购发布时间
     */
    public java.util.Date getBuyTime() {
        return buyTime;
    }

    /**
     * 求购发布时间
     */
    public void setBuyTime(java.util.Date buyTime) {
        this.buyTime = buyTime;
    }
    /**
     * 停止求购时间
     */
    public java.util.Date getEndbuyTime() {
        return endbuyTime;
    }

    /**
     * 停止求购时间
     */
    public void setEndbuyTime(java.util.Date endbuyTime) {
        this.endbuyTime = endbuyTime;
    }
    /**
     * 求购状态(0-求购中,1-已关闭，2-暂存)
     */
    public java.lang.Integer getStatus() {
        return status;
    }

    /**
     * 求购状态(0-求购中,1-已关闭，2-暂存)
     */
    public void setStatus(java.lang.Integer status) {
        this.status = status;
    }
    /**
     * 关闭类型0-手动关闭,1-到期关闭
     */
    public java.lang.Integer getCloseType() {
        return closeType;
    }

    /**
     * 关闭类型0-手动关闭,1-到期关闭
     */
    public void setCloseType(java.lang.Integer closeType) {
        this.closeType = closeType;
    }
    /**
     * 关闭人
     */
    public java.lang.Long getCloser() {
        return closer;
    }

    /**
     * 关闭人
     */
    public void setCloser(java.lang.Long closer) {
        this.closer = closer;
    }
    /**
     * 求购说明
     */
    public java.lang.String getNote() {
        return note;
    }

    /**
     * 求购说明
     */
    public void setNote(java.lang.String note) {
        this.note = note;
    }
    /**
     * 标签名称
     */
    public java.lang.String getLabelName() {
        return labelName;
    }

    /**
     * 标签名称
     */
    public void setLabelName(java.lang.String labelName) {
        this.labelName = labelName;
    }
    
}
